==> haskell-bifunctors-5.5.3-7-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-bifunctors.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: bifunctors
version: 5.5.3
id: bifunctors-5.5.3-BWXHhQ4CJ6lH9XkjWypCPC
key: bifunctors-5.5.3-BWXHhQ4CJ6lH9XkjWypCPC
license: BSD-3-Clause
copyright: Copyright (C) 2008-2016 Edward A. Kmett
maintainer: Edward A. Kmett <ekmett@gmail.com>
author: Edward A. Kmett
stability: provisional
homepage: http://github.com/ekmett/bifunctors/
synopsis: Bifunctors
description:
    Bifunctors.
category: Data, Functors
abi: 7846388f25f824ab5253f4b4cfd76886
exposed: True
exposed-modules:
    Data.Biapplicative Data.Bifunctor.Biff Data.Bifunctor.Clown
    Data.Bifunctor.Fix Data.Bifunctor.Flip Data.Bifunctor.Functor
    Data.Bifunctor.Join Data.Bifunctor.Joker Data.Bifunctor.Product
    Data.Bifunctor.Sum Data.Bifunctor.TH Data.Bifunctor.Tannen
    Data.Bifunctor.Wrapped
hidden-modules: Data.Bifunctor.TH.Internal Paths_bifunctors
import-dirs: /usr/lib/ghc-8.4.3/site-local/bifunctors-5.5.3
library-dirs: /usr/lib/ghc-8.4.3/site-local/bifunctors-5.5.3
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.4.3/bifunctors-5.5.3
hs-libraries: HSbifunctors-5.5.3-BWXHhQ4CJ6lH9XkjWypCPC
depends:
    base-4.11.1.0 base-orphans-0.8-7TUTOog0a6ABMwxqX4KVFf
    comonad-5.0.4-3a3eb7VXjyTBj8gF3eWZTj containers-0.5.11.0
    template-haskell-2.13.0.0
    th-abstraction-0.2.8.0-Ct896m4STpK8GA15Cl5y88 transformers-0.5.5.0
    tagged-0.8.6-8akQ1aZG2N2GFJpoB5eGXO
abi-depends: base-4.11.1.0=9da3f387598d41928f3ebf8097acf9b3
             base-orphans-0.8-7TUTOog0a6ABMwxqX4KVFf=9b46f2d228c37bba01819975641afd14
             comonad-5.0.4-3a3eb7VXjyTBj8gF3eWZTj=8fdc4dc9241d421d8cd18312b441b5e8
             containers-0.5.11.0=7795138514357bd2e41eaf59b6cfce4f
             template-haskell-2.13.0.0=1ce4a454c5861830bbdedc46baa462f3
             th-abstraction-0.2.8.0-Ct896m4STpK8GA15Cl5y88=303b2de9b3dc2b2e86b6ff0f8de41846
             transformers-0.5.5.0=633c3e5ec737c360775b452ce9aa1e0b
             tagged-0.8.6-8akQ1aZG2N2GFJpoB5eGXO=4bf567357cce5e796341c1faefad6985
haddock-interfaces: /usr/share/doc/haskell-bifunctors/html/bifunctors.haddock
haddock-html: /usr/share/doc/haskell-bifunctors/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-bifunctors-5.5.3-10-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-bifunctors.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: bifunctors
version: 5.5.3
id: bifunctors-5.5.3-9jqaoheYI3yJSBk86s0M4s
key: bifunctors-5.5.3-9jqaoheYI3yJSBk86s0M4s
license: BSD-3-Clause
copyright: Copyright (C) 2008-2016 Edward A. Kmett
maintainer: Edward A. Kmett <ekmett@gmail.com>
author: Edward A. Kmett
stability: provisional
homepage: http://github.com/ekmett/bifunctors/
synopsis: Bifunctors
description:
    Bifunctors.
category: Data, Functors
abi: 3d3c9e00ff840d6fb7ed94064910112e
exposed: True
exposed-modules:
    Data.Biapplicative Data.Bifunctor.Biff Data.Bifunctor.Clown
    Data.Bifunctor.Fix Data.Bifunctor.Flip Data.Bifunctor.Functor
    Data.Bifunctor.Join Data.Bifunctor.Joker Data.Bifunctor.Product
    Data.Bifunctor.Sum Data.Bifunctor.TH Data.Bifunctor.Tannen
    Data.Bifunctor.Wrapped
hidden-modules: Data.Bifunctor.TH.Internal Paths_bifunctors
import-dirs: /usr/lib/ghc-8.4.3/site-local/bifunctors-5.5.3
library-dirs: /usr/lib/ghc-8.4.3/site-local/bifunctors-5.5.3
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.4.3/bifunctors-5.5.3
hs-libraries: HSbifunctors-5.5.3-9jqaoheYI3yJSBk86s0M4s
depends:
    base-4.11.1.0 base-orphans-0.8-IMe9IACIp8aFSEynTCteC2
    comonad-5.0.4-6EAk2fiOHry3dCQFwOV2DJ containers-0.5.11.0
    template-haskell-2.13.0.0
    th-abstraction-0.2.8.0-Ct896m4STpK8GA15Cl5y88 transformers-0.5.5.0
    tagged-0.8.6-8akQ1aZG2N2GFJpoB5eGXO
abi-depends: base-4.11.1.0=9da3f387598d41928f3ebf8097acf9b3
             base-orphans-0.8-IMe9IACIp8aFSEynTCteC2=9d1eb5b04157e6a04f0c8e24c12b6390
             comonad-5.0.4-6EAk2fiOHry3dCQFwOV2DJ=33f3aad5ccd0483535d25476e9626028
             containers-0.5.11.0=7795138514357bd2e41eaf59b6cfce4f
             template-haskell-2.13.0.0=1ce4a454c5861830bbdedc46baa462f3
             th-abstraction-0.2.8.0-Ct896m4STpK8GA15Cl5y88=303b2de9b3dc2b2e86b6ff0f8de41846
             transformers-0.5.5.0=633c3e5ec737c360775b452ce9aa1e0b
             tagged-0.8.6-8akQ1aZG2N2GFJpoB5eGXO=4bf567357cce5e796341c1faefad6985
haddock-interfaces: /usr/share/doc/haskell-bifunctors/html/bifunctors.haddock
haddock-html: /usr/share/doc/haskell-bifunctors/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
